@@ -205,8 +205,8 @@ def label_counts_without_torch(labels):
 
 def label_counts(labels):
     assert labels.ndim == 1
-    torch_labels = torch.tensor(labels)
-    torch_unique = torch_labels.unique()
+    torch_labels = torch.tensor(labels).long()
+    torch_unique = torch_labels.unique().long()
     max_label = torch_unique.max()
     multihot = torch.zeros(max_label+1).long().index_put(indices=[torch_labels],values=torch.ones_like(torch_labels),accumulate=True)
     return {x.item():multihot[x].item() for x in torch_unique}
