@@ -1,6 +1,7 @@
 import torch
 import numpy as np
 import os
+import matplotlib.pyplot as plt
 
 def to_float_tensor(item): return item.float().div_(255.)
 def add_colour_dimension(item):
@@ -63,3 +64,14 @@ def cudify(x): return torch.tensor(x,device='cuda')
 def print_tensors(*tensors):
     """Only works for one-element tensors"""
     print(*[t.item() for t in tensors])
+
+def display_image(t):
+    a = numpyify(t.squeeze())
+    if a.ndim==2:
+        plt.imshow(a); plt.show()
+    elif a.ndim==3 and a.shape[0]==3:
+        plt.imshow(np.transpose(a,(1,2,0))); plt.show()
+    elif a.ndim==3 and a.shape[2]==3:
+        plt.imshow(a); plt.show()
+    else:
+        raise TypeError(f"invalid tensor shape {a.shape} for displaying images")
